Module endpoint_urls

Module endpoint_urls 

Structs

EndpointUrl
HTTP/WSS URL pair for a single network on a multichain endpoint.
GetEndpointUrlsData
Inner data for get_endpoint_urls — the http/wss URLs for the endpoint and, when the endpoint is multichain, a per-network map of additional URLs.
GetEndpointUrlsResponse
Response from get_endpoint_urls.