Module sql

Module sql 

Structs

ChainSchema
Response from get_schema: the schema for a single chain/cluster.
ColumnMeta
Metadata describing a single column in a query result set.
ColumnSchema
A single column in a table schema.
QueryParams
Parameters for query.
QueryResponse
Response from query.
QueryStatistics
Execution statistics returned alongside query results.
SqlApiClient
Client for the Quicknode SQL Explorer. Executes SQL queries against indexed blockchain data and fetches the database schema.
TableSchema
Schema for a single table.