pub struct AzureAttributes {
pub storage_account: String,
pub sas_token: String,
pub container: String,
pub compression: String,
pub file_type: String,
pub max_retry: i32,
pub retry_interval_sec: i32,
pub blob_prefix: Option<String>,
}Expand description
Configuration for delivering stream batches to Azure Blob Storage.
Fields
storage_account: StringAzure storage account name.
sas_token: StringSAS token used to authorize writes.
container: StringContainer that receives written blobs.
compression: StringCompression applied to written blobs (e.g. none, gzip).
file_type: StringFile format/extension for written blobs (e.g. .json).
max_retry: i32Maximum number of retry attempts for a failed write.
retry_interval_sec: i32Seconds to wait between retry attempts.
blob_prefix: Option<String>Optional name prefix prepended to each written blob.