ClickhouseAttributes

Struct ClickhouseAttributes 

pub struct ClickhouseAttributes {
Show 15 fields pub hosts: String, pub database: String, pub username: String, pub password: String, pub table_name: String, pub default_table_engine_opts: String, pub default_granularity: i32, pub default_compression: String, pub default_index_type: String, pub max_retry: i32, pub retry_interval_sec: i32, pub disable_datetime_precision: Option<bool>, pub dont_support_rename_column: Option<bool>, pub dont_support_empty_default_value: Option<bool>, pub skip_initialize_with_version: Option<bool>,
}
Configuration for delivering stream batches to a ClickHouse cluster.

Fields

hosts: String

Comma-separated list of ClickHouse hosts.

database: String

Database name.

username: String

Username used to authenticate.

password: String

Password used to authenticate.

table_name: String

Destination table for inserted rows.

default_table_engine_opts: String

Default table engine options applied when a table is created.

default_granularity: i32

Default index granularity for created tables.

default_compression: String

Default compression codec for created tables.

default_index_type: String

Default secondary index type for created tables.

max_retry: i32

Maximum number of retry attempts for a failed write.

retry_interval_sec: i32

Seconds to wait between retry attempts.

disable_datetime_precision: Option<bool>

Disable datetime precision for older ClickHouse versions that don’t support it.

dont_support_rename_column: Option<bool>

Enable when the target ClickHouse server does not support RENAME COLUMN.

dont_support_empty_default_value: Option<bool>

Enable when the target ClickHouse server does not support empty default values.

skip_initialize_with_version: Option<bool>

Skip writing version metadata during initialization.