pub struct SnowflakeAttributes {
pub account: String,
pub host: String,
pub port: i32,
pub protocol: String,
pub database: String,
pub schema: String,
pub warehouse: String,
pub username: String,
pub password: String,
pub max_retry: i32,
pub retry_interval_sec: i32,
pub table_name: Option<String>,
}Expand description
Configuration for delivering stream batches to a Snowflake data warehouse.
Fields
account: StringSnowflake account identifier.
host: StringSnowflake host.
port: i32Snowflake port.
protocol: StringConnection protocol (e.g. https).
database: StringDatabase name.
schema: StringSchema within the database.
warehouse: StringWarehouse used to run inserts.
username: StringUsername used to authenticate.
password: StringPassword used to authenticate.
max_retry: i32Maximum number of retry attempts for a failed write.
retry_interval_sec: i32Seconds to wait between retry attempts.
table_name: Option<String>Optional destination table for inserted rows.