Structs
- Endpoint
Url - HTTP/WSS URL pair for a single network on a multichain endpoint.
- GetEndpoint
Urls Data - Inner data for
get_endpoint_urls— the http/wss URLs for the endpoint and, when the endpoint is multichain, a per-network map of additional URLs. - GetEndpoint
Urls Response - Response from
get_endpoint_urls.